@@ -1,7 +1,7 @@
 #' @method qread csv
 #' @export
-qread.csv <- function(file, type, check.names=FALSE, ...) {
-	read.table(file, header=TRUE, sep=",", check.names=check.names, ...)
+qread.csv <- function(file, type, check.names=FALSE, quote="\"", ...) {
+	read.table(file, header=TRUE, sep=",", quote=quote, check.names=check.names, ...)
 }
 
 #' @method qwrite csv
