@@ -1,7 +1,7 @@
 #' @method qread json
 #' @export
 qread.json <- function(file, type, ...) {
-	require(jsonlite);
+	.check_package("jsonlite");
 
 	jsonlite::unserializeJSON(paste(readLines(file), collapse="\n"), ...)
 }
@@ -9,7 +9,7 @@ qread.json <- function(file, type, ...) {
 #' @method qwrite json
 #' @export
 qwrite.json <- function(x, file, type, append=FALSE, ...) {
-	require(jsonlite);
+	.check_package("jsonlite");
 
 	cat(jsonlite::serializeJSON(x, ...), sep="", file=file, append=append)
 }
